@@ -2,10 +2,10 @@ package exact;
 # ABSTRACT: Perl pseudo pragma to enable strict, warnings, features, mro, filehandle methods
 
 use 5.010;
-use strict;
-use warnings;
+use strictures 2;
+use namespace::autoclean;
 
-our $VERSION = '1.03'; # VERSION
+our $VERSION = '1.04'; # VERSION
 
 use feature    ();
 use mro        ();
@@ -27,7 +27,7 @@ my %experiments = (
     26 => ['declared_refs'],
 );
 
-my @function_list  = qw( nostrict nowarnings noc3 nobundle noexperiments noskipexperimentalwarnings );
+my @function_list  = qw( nostrictures noc3 nobundle noexperiments noskipexperimentalwarnings );
 my @feature_list   = map { @$_ } values %features, values %experiments;
 my ($perl_version) = $^V =~ /^v5\.(\d+)/;
 
@@ -53,9 +53,8 @@ sub import {
     }
 
     mro::set_mro( scalar caller(), 'c3' ) unless ( grep { $_ eq 'noc3' } @functions );
-
-    strict->import unless ( grep { $_ eq 'nostrict' } @functions );
-    warnings->import unless ( grep { $_ eq 'nowarnings' } @functions );
+    strictures->import unless ( grep { $_ eq 'nostrictures' } @functions );
+    namespace::autoclean->import( '-cleanee' => scalar caller() );
 
     if (@bundles) {
         my ($bundle) = sort { $b <=> $a } @bundles;
@@ -93,7 +92,7 @@ exact - Perl pseudo pragma to enable strict, warnings, features, mro, filehandle
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/exact.svg)](https://travis-ci.org/gryphonshafer/exact)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/exact/badge.png)](https://coveralls.io/r/gryphonshafer/exact)
@@ -102,13 +101,13 @@ version 1.03
 
 Instead of this:
 
-    use strict;
-    use warnings;
+    use strictures 2;
     use feature ':5.23';
     use feature qw( signatures refaliasing bitwise );
     use mro 'c3';
     use IO::File;
     use IO::Handle;
+    use namespace::autoclean;
 
     no warnings "experimental::signatures";
     no warnings "experimental::refaliasing";
@@ -121,7 +120,7 @@ Type this:
 Or for finer control, add some trailing modifiers like a line of the following:
 
     use exact '5.20';
-    use exact qw( 5.16 nowarnings noc3 noexperiments );
+    use exact qw( 5.16 nostrictures noc3 noexperiments );
     use exact qw( noexperiments fc signatures );
 
 =head1 DESCRIPTION
@@ -136,11 +135,7 @@ By default, L<exact> will:
 
 =item *
 
-enable L<strict>
-
-=item *
-
-enable L<warnings>
+enable L<strictures> (version 2)
 
 =item *
 
@@ -164,13 +159,9 @@ enable methods on filehandles
 
 L<exact> supports the following import flags:
 
-=head2 C<nostrict>
+=head2 C<nostrictures>
 
-This skips turning on the L<strict> pragma.
-
-=head2 C<nowarnings>
-
-This skips turning on the L<warnings> pragma.
+This skips using the L<strictures> setup.
 
 =head2 C<noc3>
 
